..
    This file is automatically generated. Do not make
    changes as these will be overwritten. Rather edit
    the docstrings in the source code.

``yaff.sampling`` -- Phase-space sampling
#########################################




``yaff.sampling.dof`` -- Abstraction layer for degrees of freedom
=================================================================

.. automodule:: yaff.sampling.dof
    :members:


``yaff.sampling.harmonic`` -- Harmonic models
=============================================

.. automodule:: yaff.sampling.harmonic
    :members:


``yaff.sampling.io`` -- Trajectory writers
==========================================

.. automodule:: yaff.sampling.io
    :members:


``yaff.sampling.iterative`` -- Base class for iterative algorithms
==================================================================

.. automodule:: yaff.sampling.iterative
    :members:


``yaff.sampling.npt`` -- Barostats
==================================

.. automodule:: yaff.sampling.npt
    :members:


``yaff.sampling.nvt`` -- Thermostats
====================================

.. automodule:: yaff.sampling.nvt
    :members:


``yaff.sampling.opt`` -- Geometry/Cell optimization
===================================================

.. automodule:: yaff.sampling.opt
    :members:


``yaff.sampling.trajectory`` -- Computations on a reference trajectory
======================================================================

.. automodule:: yaff.sampling.trajectory
    :members:


``yaff.sampling.utils`` -- Auxiliary routines for initial velocities
====================================================================

.. automodule:: yaff.sampling.utils
    :members:


``yaff.sampling.verlet`` -- Generic Verlet integrator
=====================================================

.. automodule:: yaff.sampling.verlet
    :members:
